Cite us
=======

.. hint::

   You can cite the software from within Python by running :code:`nk.cite()`

Main publication
----------------

You can cite the **main publication** for *NeuroKit2* as follows:

- Makowski, D., Pham, T., Lau, Z. J., Brammer, J. C., Lespinasse, F., Pham, H., Schölzel, C., & Chen, S. A. (2021). NeuroKit2: A Python toolbox for neurophysiological signal processing. *Behavior Research Methods*, 53(4), 1689-1696. https://doi.org/10.3758/s13428-020-01516-y

.. code-block:: none
   :caption: The bibtex citation information for NeuroKit2

    @article{Makowski2021neurokit,
        author = {Dominique Makowski and Tam Pham and Zen J. Lau and Jan C. Brammer and Fran{\c{c}}ois Lespinasse and Hung Pham and Christopher Schölzel and S. H. Annabel Chen},
        title = {{NeuroKit}2: A Python toolbox for neurophysiological signal processing},
        journal = {Behavior Research Methods},
        volume = {53},
        number = {4},
        pages = {1689--1696},
        publisher = {Springer Science and Business Media {LLC}},
        doi = {10.3758/s13428-020-01516-y},
        url = {https://doi.org/10.3758%2Fs13428-020-01516-y},
        year = 2021,
        month = {feb}
    }

Cite Documentation
-------------------

.. note::

   We are interested in finding a way of crediting all the major contributors in a satisfactory manner. If you have some idea on that front, please let us know.


If you want to additionally **reference the manual** (to refer to the content of this documentation), you can add the following reference:


- Makowski, D. (2021). *Neurophysiological Data Analysis with NeuroKit2*. NeuroKit. https://neuropsychology.github.io/NeuroKit/

Other related papers
---------------------

- Heart Rate Variability in Psychology: A Review of HRV Indices and an Analysis Tutorial `(Pham et al., 2021) <https://doi.org/10.3390/s21123998>`_